﻿using System;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Collections.ObjectModel;

namespace sql2008Layer
{
    public partial class _Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                /*********** MAP SETTINGS ***************************************************************************************************************************************/
                // Unités
                Map1.MapUnit = GeographyUnit.Meter;

                // Logo Thinkgeo
                Map1.MapTools.Logo.Enabled = false;

                // Couleur de fond
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

                // Etendue par défaut
                Map1.CurrentExtent = new RectangleShape(new PointShape(148140.02981431, 6427083.1226986), new PointShape(738845.38429635, 6085256.7322686)); // Champagne
                Map1.RestrictedExtent = new RectangleShape(new PointShape(148140.02981431, 6427083.1226986), new PointShape(738845.38429635, 6085256.7322686)); // Champagne

                // Overlay switcher
                Map1.MapTools.OverlaySwitcher.Enabled = true;
                Map1.MapTools.OverlaySwitcher.BackgroundColor = new GeoColor(50, GeoColor.StandardColors.White);
                Map1.MapTools.OverlaySwitcher.RoundedCornerColor = new GeoColor(50, GeoColor.StandardColors.White);
                Map1.MapTools.OverlaySwitcher.BaseOverlayTitle = "Choix du fond de carte:";
                Map1.MapTools.OverlaySwitcher.DynamicOverlayTitle = "<br />Affichage des calques:";

                // Keyboard control
                Map1.MapTools.KeyboardMapTool.Enabled = false;

                // Measure tool
                Map1.MapTools.MeasureMapTool.Enabled = false;

                // Mini Map tool
                Map1.MapTools.MiniMap.Enabled = true;

                // Mouse coordinates
                Map1.MapTools.MouseCoordinate.Enabled = false;

                // Scale line
                Map1.MapTools.ScaleLine.Enabled = false;



                /*
                //*********** GOOGLE MAPS **************************************************************************************************************************************/
                GoogleOverlay googleMapsOverlay = new GoogleOverlay("googleMapsOverlay");
                googleMapsOverlay.Name = "Google Maps";
                googleMapsOverlay.GoogleMapType = GoogleMapType.Hybrid;
                googleMapsOverlay.IsBaseOverlay = true;
                Map1.CustomOverlays.Add(googleMapsOverlay);



                /*
                //*********** EMPTY OVERLAY **************************************************************************************************************************************/
                LayerOverlay emptyLayerOverlay = new LayerOverlay("emptyLayerOverlay");
                emptyLayerOverlay.Name = "Aucun";
                emptyLayerOverlay.IsBaseOverlay = true;
                emptyLayerOverlay.SetBaseEpsgProjection("EPSG:900913"); // Spherical Mercator
                Map1.CustomOverlays.Add(emptyLayerOverlay);



                /*
                //*********** MsSql2008FeatureLayer **************************************************************************************************************************************/
                MsSql2008FeatureLayer sql2008FeatureLayer = new MsSql2008FeatureLayer();
                ((MsSql2008FeatureSource)(sql2008FeatureLayer.FeatureSource)).ExecutingSqlStatement += new EventHandler<ExecutingSqlStatementMsSql2008FeatureSourceEventArgs>(Sql2008featureSource_ExecutingSqlStatement);
                sql2008FeatureLayer.ConnectionString = sql2008Layer.Properties.Settings.Default.connString;
                sql2008FeatureLayer.Name = "MsSql2008FeatureLayer";
                sql2008FeatureLayer.TableName = "features";
                sql2008FeatureLayer.FeatureIdColumn = "featureID";
                sql2008FeatureLayer.CustomGeometryColumnName = "featureShape";
                //sql2008FeatureLayer.WhereClause = "WHERE featureID != ''";
                sql2008FeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.County1;
                sql2008FeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                Proj4Projection proj4 = new Proj4Projection();
                proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);  // Epsg4326
                proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString(); // SphericalMercator
                sql2008FeatureLayer.FeatureSource.Projection = proj4;

                sql2008FeatureLayer.FeatureSource.Open();
                Collection<BaseShape> shapes = new Collection<BaseShape>();
                foreach (Feature feature in sql2008FeatureLayer.FeatureSource.GetAllFeatures(ReturningColumnsType.AllColumns))
                {
                    BaseShape shape = feature.GetShape();
                    shapes.Add(shape);
                    Console.Write(feature.ColumnValues.ToString());
                }
                sql2008FeatureLayer.FeatureSource.Close();

                RectangleShape totalExtent = null;
                foreach (BaseShape item in shapes)
                {
                    if (totalExtent == null)
                    {
                        totalExtent = item.GetBoundingBox();
                    }
                    else
                    {
                        totalExtent.ExpandToInclude(item.GetBoundingBox());
                    }
                }
                
                LayerOverlay sql2008LayerOverlay = new LayerOverlay("sql2008LayerOverlay");
                sql2008LayerOverlay.Name = "sql2008LayerOverlay";
                sql2008LayerOverlay.IsBaseOverlay = false;
                sql2008LayerOverlay.Opacity = 0.5F;
                sql2008LayerOverlay.Layers.Add(sql2008FeatureLayer);
                Map1.CustomOverlays.Add(sql2008LayerOverlay);

                RectangleShape boundingBox = new RectangleShape(393552.406996615, 6340655.66426205, 516969.043014608, 6247854.21039292);
                try
                {
                    RectangleShape RS = totalExtent;
                    boundingBox = RS;
                }
                catch (Exception err)
                {
                    Console.Write(err.Message + "\r\n\r\n" + err.Source + "\r\n\r\n" + err.TargetSite + "\r\n\r\n" + err.InnerException + "\r\n\r\n" + err.Data);
                }
                Map1.CurrentExtent = boundingBox;
            }
        }


        /*********** POUR DEBUG SQL QUERY *****************************************************************************************************************************************/
        // Ajouter: ((MsSql2008FeatureSource)(sql2008FeatureLayer.FeatureSource)).ExecutingSqlStatement += new EventHandler<ExecutingSqlStatementMsSql2008FeatureSourceEventArgs>(Sql2008featureSource_ExecutingSqlStatement);
        private void Sql2008featureSource_ExecutingSqlStatement(object sender, ExecutingSqlStatementMsSql2008FeatureSourceEventArgs e)
        {
            if (e.ExecutingSqlStatementType == ExecutingSqlStatementType.CommitTransactionEx)
            {
                string sql = e.SqlStatement;
            }
        }
    }
}
